import { useState, useEffect } from 'react';

function useQuery() {
  var search = window.location.search;

  var _useState = useState({}),
      query = _useState[0],
      setQuery = _useState[1];

  useEffect(function () {
    if (typeof window !== "undefined") {
      var urlSearchParams = new URLSearchParams(search);
      var params = Object.fromEntries(urlSearchParams.entries());
      setQuery(params);
    } else {
      setQuery({});
    }

    return function () {
      setQuery({});
    };
  }, [search]);
  return query;
}

function messageError(error) {
  return "Honey Hook Error: " + error.name + ": " + error.message;
}

function calcValuesOfDownCountDate(countDown) {
  try {
    if (typeof countDown !== "number") {
      throw new Error("Date is not valid");
    }

    if (countDown < 0) {
      throw new Error("Date is not valid");
    } // calculate time left


    var days = Math.floor(countDown / (1000 * 60 * 60 * 24));
    var hours = Math.floor(countDown % (1000 * 60 * 60 * 24) / (1000 * 60 * 60));
    var minutes = Math.floor(countDown % (1000 * 60 * 60) / (1000 * 60));
    var seconds = Math.floor(countDown % (1000 * 60) / 1000);
    return {
      days: days,
      hours: hours,
      minutes: minutes,
      seconds: seconds
    };
  } catch (error) {
    console.error(messageError(error));
    return {
      days: 0,
      hours: 0,
      minutes: 0,
      seconds: 0
    };
  }
}

function useCountdownDate(date) {
  var parseDate = new Date(date).getTime();

  var _useState = useState(parseDate - new Date().getTime()),
      countDown = _useState[0],
      setCountDown = _useState[1];

  var _calcValuesOfDownCoun = calcValuesOfDownCountDate(countDown),
      days = _calcValuesOfDownCoun.days,
      hours = _calcValuesOfDownCoun.hours,
      minutes = _calcValuesOfDownCoun.minutes,
      seconds = _calcValuesOfDownCoun.seconds;

  useEffect(function () {
    var downInterval = setInterval(function () {
      setCountDown(parseDate - new Date().getTime());
    }, 1000);
    return function () {
      return clearInterval(downInterval);
    };
  }, [parseDate]);
  return {
    days: days,
    hours: hours,
    minutes: minutes,
    seconds: seconds
  };
}

function useOnClickOutSide(ref, handler) {
  useEffect(function () {
    var listener = function listener(event) {
      // Do nothing if clicking ref's element or descendent elements
      if (!ref.current || ref.current.contains(event.target)) {
        return;
      }

      handler(event);
    };

    document.addEventListener("mousedown", listener);
    document.addEventListener("touchstart", listener);
    return function () {
      document.removeEventListener("mousedown", listener);
      document.removeEventListener("touchstart", listener);
    };
  }, // Add ref and handler to effect dependencies
  // It's worth noting that because passed in handler is a new ...
  // ... function on every render that will cause this effect ...
  // ... callback/cleanup to run every render. It's not a big deal ...
  // ... but to optimize you can wrap handler in useCallback before ...
  // ... passing it into this hook.
  [ref, handler]);
}

export { useCountdownDate, useOnClickOutSide, useQuery };
//# sourceMappingURL=react-honey-hooks.esm.js.map
